# Algo Trader Package

This is a package for the use of [algoinvest.online](https://www.algoinvst.online)

It can connect to a the Signal Provider API and execute orders on Bitmex and other providers.

# Install on pythonanywhere or on your PC

python -m pip install --user git+https://github.com/dignitas123/algo_trader